Addr

Enum Addr 

pub enum Addr {
Show 59 variants PrimaryEngineController, SecondaryEngineController, PrimaryTransmissionController, TransmissionShiftSelector, Brakes, Retarder, CruiseControl, FuelSystem, SteeringController, InstrumentCluster, ClimateControl1, Compass, BodyController, OffVehicleGateway, DidVid, RetarderExhaustEngine1, HeadwayController, Suspension, CabController, TirePressureController, LightingControlModule, ClimateControl2, ExhaustEmissionController, AuxiliaryHeater, ChassisController, CommunicationsUnit, Radio, SafetyRestraintSystem, AftertreatmentControlModule, MultiPurposeCamera, SwitchExpansionModule, AuxillaryGaugeSwitchPack, Iteris, QualcommPeopleNetTranslatorBox, StandAloneRealTimeClock, CenterPanel1, CenterPanel2, CenterPanel3, CenterPanel4, CenterPanel5, WabcoOnGuardRadar, SecondaryInstrumentCluster, OffboardDiagnostics, Trailer3Bridge, Trailer2Bridge, Trailer1Bridge, SafetyDirectProcessor, ForwardRoadImageProcessor, LeftRearDoorPod, RightRearDoorPod, DoorController1, DoorController2, Tachograph, HybridSystem, AuxiliaryPowerUnit, ServiceTool, SourceAddressRequest0, SourceAddressRequest1, Unknown(u8),
}
The Addr enum represents various types of electronic control units (ECUs) and modules commonly found in automotive and heavy-duty vehicle networks. Each variant corresponds to a specific ECU or system component that communicates over the network.

Variants



PrimaryEngineController



SecondaryEngineController



PrimaryTransmissionController



TransmissionShiftSelector



Brakes



Retarder



CruiseControl



FuelSystem



SteeringController



InstrumentCluster



ClimateControl1



Compass



BodyController



OffVehicleGateway



DidVid



RetarderExhaustEngine1



HeadwayController



Suspension



CabController



TirePressureController



LightingControlModule



ClimateControl2



ExhaustEmissionController



AuxiliaryHeater



ChassisController



CommunicationsUnit



Radio



SafetyRestraintSystem



AftertreatmentControlModule



MultiPurposeCamera



SwitchExpansionModule



AuxillaryGaugeSwitchPack



Iteris



QualcommPeopleNetTranslatorBox



StandAloneRealTimeClock



CenterPanel1



CenterPanel2



CenterPanel3



CenterPanel4



CenterPanel5



WabcoOnGuardRadar



SecondaryInstrumentCluster



OffboardDiagnostics



Trailer3Bridge



Trailer2Bridge



Trailer1Bridge



SafetyDirectProcessor



ForwardRoadImageProcessor



LeftRearDoorPod



RightRearDoorPod



DoorController1



DoorController2



Tachograph



HybridSystem



AuxiliaryPowerUnit



ServiceTool



SourceAddressRequest0



SourceAddressRequest1



Unknown(u8)